@@ -5,7 +5,8 @@ try:
 
     class CustomDomain(Domain):
         def __init__(self):
-            super(CustomDomain, self).__init__(translations.__path__[0], domain='admin')
+            super(CustomDomain, self).__init__(translations.__path__[0],
+                  domain='admin')
 
         def get_translations_path(self, ctx):
             print ctx
