@@ -111,15 +111,17 @@ class BaseModelAdmin(BaseView):
 
         model_form = self.get_model_form()
         converter = self.get_converter()
+        if isinstance(converter, type):
+            converter = converter()
         form = model_form(self.model, base_class=BaseForm, only=only,
                           exclude=exclude, field_args=self.field_args,
-                          converter=converter())
+                          converter=converter)
 
         form.readonly_fields = self.readonly_fields
         return form
 
     def get_add_form(self):
-        return self.get_form(adding=True)
+        return self.get_form()
 
     def get_objects(self, *pks):
         raise NotImplemented()
@@ -183,8 +185,8 @@ class BaseModelAdmin(BaseView):
                     return self.dispatch_save_redirect(instance)
                 except Exception, ex:
                     print traceback.format_exc()
-                    if self.session:
-                        self.session.rollback()
+                    # if self.session:
+                    #     self.session.rollback()
                     flash(gettext('Failed to add model. %(error)s',
                           error=str(ex)), 'error')
 
